@@ -81,7 +81,7 @@ suffix_refresh <- function(){
       rez <- data.frame(suffixes = suff[!iscomment],
                  comments = suff[which(iscomment)[1]], stringsAsFactors = FALSE)
     }
-    rez
+    return(rez)
   }))
   ## this is the old way
   #suffix_dataset <- results[!grepl(x = results, pattern = "//", fixed = TRUE) & !results == ""]
@@ -147,7 +147,8 @@ suffix_extract <- function(domains, suffixes = NULL){
   rev_domains <- reverse_strings(tolower(domains))
   matched_suffixes <- triebeard::longest_match(urltools_env$suff_trie, rev_domains)
   has_wildcard <- matched_suffixes %in% urltools_env$is_wildcard
-  return(finalise_suffixes(domains, matched_suffixes, has_wildcard))
+  is_suffix = domains %in% urltools_env$cleaned_suffixes
+  return(finalise_suffixes(domains, matched_suffixes, has_wildcard, is_suffix))
 }
 
 #' @title Dataset of top-level domains (TLDs)
@@ -192,7 +193,7 @@ suffix_extract <- function(domains, suffixes = NULL){
 #'@export
 tld_refresh <- function(){
   raw_tlds <- readLines("http://data.iana.org/TLD/tlds-alpha-by-domain.txt", warn = FALSE)
-  raw_tlds <- tolower(raw_tlds[!grepl(x = raw_tlds, pattern = "(#|--)")])
+  raw_tlds <- tolower(raw_tlds[!grepl(x = raw_tlds, pattern = "#", fixed = TRUE)])
   return(raw_tlds)
 }
 
