@@ -15,5 +15,7 @@ NULL
 #'@rdname param_get
 #'@export
 url_parameters <- function(urls, parameter_names){
+  .Deprecated("param_get",
+              old = as.character(sys.call(sys.parent()))[1L])
   return(param_get(urls, parameter_names))
 }
\ No newline at end of file
