@@ -8,6 +8,14 @@ test_that("Check encoding does does not encode pre-path slashes", {
   expect_that(url_encode("https://foo.org/bar/"), equals("https://foo.org/bar%2f"))
 })
 
+test_that("Check encoding can handle NAs", {
+  expect_that(url_encode(c("https://foo.org/bar/", NA)), equals(c("https://foo.org/bar%2f", NA)))
+})
+
+test_that("Check decoding can handle NAs", {
+  expect_that(url_decode(c("https://foo.org/bar%2f", NA)), equals(c("https://foo.org/bar/", NA)))
+})
+
 test_that("Check decoding and encoding are equivalent", {
   
   url <- "Hinrichtung_auf_dem_Altst%c3%a4dter_Ring.JPG%2f120px-Hinrichtung_auf_dem_Altst%c3%a4dter_Ring.JPG"
